<?php
/**
 * Admin notice to warn users that they need to Regenerate Critical CSS. Shows whenever the module is
 * active, but no Critical CSS is in the cache.
 *
 * @package automattic/jetpack-boost
 */

namespace Automattic\Jetpack_Boost\Modules\Critical_CSS;

use Automattic\Jetpack_Boost\Admin\Admin_Notice;

/**
 * Class Regenerate_Admin_Notice
 */
class Regenerate_Admin_Notice extends Admin_Notice {

	const SLUG = 'critical-css-regenerate';
	/**
	 * Possible reasons the Critical CSS may not be generated.
	 */
	const REASON_UNKNOWN      = 'unknown';
	const REASON_THEME_CHANGE = 'theme_change'; // Cache cleared due to env change. e.g.: theme changed.

	/**
	 * The reason to regenerate.
	 *
	 * @var int|mixed
	 */
	private $reason;

	/**
	 * Create a new Regenerate_Admin_Notice.
	 *
	 * @param string $reason The reason to regenerate.
	 */
	public function __construct( $reason = self::REASON_UNKNOWN ) {
		$this->reason = $reason;
	}

	/**
	 * Returns a unique slug for this kind of admin notice.
	 *
	 * @return string
	 */
	public function get_slug() {
		return self::SLUG;
	}

	/**
	 * Returns the title of this admin notice.
	 */
	public function get_title() {
		return __( 'Jetpack Boost - Action Required', 'jetpack-boost' );
	}

	/**
	 * Get settings link text.
	 */
	protected function get_settings_link_text() {
		return __( 'Go to Jetpack Boost', 'jetpack-boost' );
	}

	/**
	 * Render this admin notice's details.
	 *
	 * @param bool $on_settings_page - True if currently viewing the Jetpack Boost settings page.
	 */
	protected function render_message( $on_settings_page ) {
		?>
			<p>
				<!-- Explanation of the problem. -->
				<?php if ( self::REASON_THEME_CHANGE === $this->reason ) : ?>
					<?php esc_html_e( 'The Critical CSS generated by Jetpack Boost was cleared due to a change in the site theme.', 'jetpack-boost' ); ?>
				<?php else : ?>
					<?php esc_html_e( 'The Critical CSS generated by Jetpack Boost was cleared.', 'jetpack-boost' ); ?>
				<?php endif ?>
			</p>
			<p>
				<!-- Action to take. -->
				<?php if ( ! $on_settings_page && $this->should_show_settings_link() ) : ?>
					<?php esc_html_e( 'You can go to the Jetpack Boost settings page to have it re-generated automatically.', 'jetpack-boost' ); ?>
				<?php else : ?>
					<?php esc_html_e( 'It will get re-generated automatically now.', 'jetpack-boost' ); ?>
				<?php endif ?>
			</p>
		<?php
	}

}
